(cl:defpackage test-io-util
  (:use :common-lisp :lisp-unit :krb-util)
  (:export ))

(cl:in-package test-io-util)

(define-test test-set-get-read-buffer-size
  (assert-equal *default-buffer-size* (get-read-buffer-size))
  (set-read-buffer-size 1234)
  (assert-equal 1234 (get-read-buffer-size))
  (set-read-buffer-size *default-buffer-size*))

(define-test test-delimited-read
  (with-input-from-string (inp "this~~is~~some~~data~~with an alternate~~line break")
    (let ((rdr (make-buffered-stream inp :line-terminator "~~"
					   :read-buffer (make-array 2 :element-type 'character)
					   :buffer-size 2)))
      (assert-equal "this~~" 		  (read-next-line rdr))
      (assert-equal "is~~"   		  (read-next-line rdr))
      (assert-equal "some~~" 		  (read-next-line rdr))
      (assert-equal "data~~" 		  (read-next-line rdr))
      (assert-equal "with an alternate~~" (read-next-line rdr))
      (assert-equal "line break"          (read-next-line rdr))
      (assert-false (read-next-line rdr)))))

(define-test test-drain-stream
  (let ((target-string "this~~is~~some~~data~~with an alternate~~line break"))
    (with-input-from-string (inp target-string)
      (let ((rdr (make-buffered-stream inp :line-terminator "~~"
					   :read-buffer (make-array 2 :element-type 'character)
					   :buffer-size 2)))
	(assert-equal target-string (drain-stream rdr))))))

(define-test test-stream->string
  (let ((target-string "foo
bar
qux
baz"))
    (with-input-from-string (inp target-string)
      (assert-equal target-string (stream->string inp)))))

(defun .nl (str)
  (concatenate 'string str krb-util:*newline*))

(define-test test-stream->lines
  (let ((target-string "foo
bar
qux
baz"))
    (with-input-from-string (inp target-string)
      (assert-equal (append (mapcar #'.nl '("foo" "bar" "qux"))
			    '("baz"))
		    (stream->lines inp)))))


